{#Usage:#}
{#    {% include "framework/header/page-header.html" with title="Foobar" subtitle="Barfoo" %}#}

{% if title %}
    <h1 class="page-header text-center mb-3">
        {{ title }}

        {% if subtitle %}
            <br>
            <small>{{ subtitle }}</small>
        {% endif %}
    </h1>
{% endif %}
