{% extends 'public/middle_box.html' %}

{% load i18n %}
{% load static %}

{% block page_title %}{% translate "Login" %}{% endblock %}

{% block middle_box_content %}
    <a href="{% url 'auth_sso_login' %}{% if request.GET.next %}?next={{request.GET.next | urlencode}}{%endif%}">
        <img class="img-responsive center-block" src="{% static 'allianceauth/authentication/img/sso/EVE_SSO_Login_Buttons_Large_Black.png' %}" alt="{% translate 'Login with Eve SSO' %}">
    </a>
{% endblock %}
